==> rs485-5.1.1.tar.bz2: rs485-5.1.1/kernel/proc/procfs.c <==
/*-------------------------------------------------
 *	Kernel version 2.2.x - 2.4.4
 *	RS485 (Moxa132, Moxa102, COM-port, LPT-port /proc support
 * 
 *	Andre Zaitsev, Olga Voziakova
 *	ovoz@sai.msu.ru
 *	$History:
 *
 *---------------------------------------- */
//#define __NO_VERSION__
 
//#include <linux/config.h>
 /*    */
//#if CONFIG_MODVERSIONS==1
//#include <linux/modversions.h>
//#endif
 
//#include <linux/module.h>
#include <linux/version.h>
 
#include <linux/proc_fs.h>
#include <linux/stat.h>

#include <mcua.h>
#include <rs485.h>

extern RS485INFO *info_port1;

static ssize_t rs_proc_write( struct file *fp, const char *buf, size_t size, loff_t *offset ) {

	RS485INFO *rs485;
	int i;

	rs485 = info_port1;
	for(i = 0; i<MAX_TASK_DEVICE+1; i++){	//	   
		rs485->device[i].number = 0;
		rs485->device[i].round_count_prev =-1;
	}
	PDEBUGG( "PROC_WRITE!\n" );
	return(1);
}


static struct file_operations rs_proc_fops = {
	write:		rs_proc_write,	// WRITE
};

#if(LINUX_VERSION_CODE < KERNEL_VERSION(2,3,98))

static struct inode_operations rs_inode_ops = {
	default_file_ops: &rs_proc_fops,
};

static struct proc_dir_entry moxa_dir = {
	0,								//low_ino => dynamic_register
	4,								//namelen
	"moxa",							//name
	S_IFDIR | S_IRUGO | S_IXUGO,	//mode
	1,0,0,							//nlink,uid,gid
};
static struct proc_dir_entry mcua0_dir = {
	0,								//low_ino => dynamic_register
	5,								//namelen
	"mcua0",						//name
	S_IFDIR | S_IRUGO | S_IXUGO,	//mode
	1,0,0,							//nlink,uid,gid
};
static struct proc_dir_entry device_proc_entry = {
	0,					//low_ino => dynamic_register
	6,					//namelen
	"device",			//name
	S_IFREG | S_IRUGO,	//mode
	1,0,0,				//nlink,uid,gid
	0,					//size
	&rs_inode_ops,		//proc_iops
};

#else

struct proc_dir_entry *p_moxa_dir = NULL;
struct proc_dir_entry *p_mcua0_dir = NULL;
struct proc_dir_entry *p_device_proc_entry = NULL;

#endif

int rs485_create_proc(void) {
#if(LINUX_VERSION_CODE < KERNEL_VERSION(2,3,98))
	proc_register(&proc_root, &moxa_dir);
	proc_register(&moxa_dir, &mcua0_dir);
	return proc_register(&mcua0_dir, &device_proc_entry);
#else
	p_moxa_dir = create_proc_entry("moxa",
			S_IFDIR | S_IRUGO | S_IXUGO, &proc_root);
	if( !p_moxa_dir ) goto FAIL0;

	p_mcua0_dir = create_proc_entry("mcua0",
			S_IFDIR | S_IRUGO | S_IXUGO, p_moxa_dir);
	if( !p_mcua0_dir ) goto FAIL1;

	p_device_proc_entry = create_proc_entry("device",
			S_IFREG | S_IRUGO, p_mcua0_dir);
	if( !p_device_proc_entry ) goto FAIL2;

	p_device_proc_entry->proc_fops = &rs_proc_fops;

	return(0);

FAIL2:
	if(p_mcua0_dir) remove_proc_entry(p_mcua0_dir->name, p_moxa_dir);
FAIL1:
	if(p_moxa_dir) remove_proc_entry(p_moxa_dir->name, &proc_root);
FAIL0:
	return(ENXIO); // no such device or address
#endif
}

void rs485_remove_proc(void) {
#if(LINUX_VERSION_CODE < KERNEL_VERSION(2,3,98))
	proc_unregister(&mcua0_dir, device_proc_entry.low_ino);
	proc_unregister(&moxa_dir, mcua0_dir.low_ino);
	proc_unregister(&proc_root, moxa_dir.low_ino);
#else
	if(p_device_proc_entry) remove_proc_entry(p_device_proc_entry->name, p_mcua0_dir);
	if(p_mcua0_dir) remove_proc_entry(p_mcua0_dir->name, p_moxa_dir);
	if(p_moxa_dir) remove_proc_entry(p_moxa_dir->name, &proc_root);
#endif
	return;
}

==> rs485-5.1.3.tar.bz2: rs485-5.1.3/kernel/proc/procfs.c <==
/*-------------------------------------------------
 *	Kernel version 2.2.x - 2.4.4
 *	RS485 (Moxa132, Moxa102, COM-port, LPT-port /proc support
 * 
 *	Andre Zaitsev, Olga Voziakova
 *	ovoz@sai.msu.ru
 *	$History:
 *
 *---------------------------------------- */
#include <linux/version.h>
 
#include <linux/proc_fs.h>
#include <linux/stat.h>

#include <mcua.h>
#include <rs485.h>

extern RS485INFO *info_port1;

static ssize_t rs_proc_write( struct file *fp, const char *buf, size_t size, loff_t *offset ) {

	RS485INFO *rs485;
	int i;

	rs485 = info_port1;
	for(i = 0; i<MAX_TASK_DEVICE+1; i++){	// initialization of the packet number
		rs485->device[i].number = 0;
		rs485->device[i].round_count_prev =-1;
	}
	PDEBUGG( "PROC_WRITE!\n" );
	return(1);
}


static struct file_operations rs_proc_fops = {
	write:		rs_proc_write,	// WRITE
};

#if(LINUX_VERSION_CODE < KERNEL_VERSION(2,3,98))

static struct inode_operations rs_inode_ops = {
	default_file_ops: &rs_proc_fops,
};

static struct proc_dir_entry moxa_dir = {
	0,								//low_ino => dynamic_register
	4,								//namelen
	"moxa",							//name
	S_IFDIR | S_IRUGO | S_IXUGO,	//mode
	1,0,0,							//nlink,uid,gid
};
static struct proc_dir_entry mcua0_dir = {
	0,								//low_ino => dynamic_register
	5,								//namelen
	"mcua0",						//name
	S_IFDIR | S_IRUGO | S_IXUGO,	//mode
	1,0,0,							//nlink,uid,gid
};
static struct proc_dir_entry device_proc_entry = {
	0,					//low_ino => dynamic_register
	6,					//namelen
	"device",			//name
	S_IFREG | S_IRUGO,	//mode
	1,0,0,				//nlink,uid,gid
	0,					//size
	&rs_inode_ops,		//proc_iops
};

#else

struct proc_dir_entry *p_moxa_dir = NULL;
struct proc_dir_entry *p_mcua0_dir = NULL;
struct proc_dir_entry *p_device_proc_entry = NULL;

#endif

int rs485_create_proc(void) {
#if(LINUX_VERSION_CODE < KERNEL_VERSION(2,3,98))
	proc_register(&proc_root, &moxa_dir);
	proc_register(&moxa_dir, &mcua0_dir);
	return proc_register(&mcua0_dir, &device_proc_entry);
#else
	p_moxa_dir = create_proc_entry("moxa",
			S_IFDIR | S_IRUGO | S_IXUGO, &proc_root);
	if( !p_moxa_dir ) goto FAIL0;

	p_mcua0_dir = create_proc_entry("mcua0",
			S_IFDIR | S_IRUGO | S_IXUGO, p_moxa_dir);
	if( !p_mcua0_dir ) goto FAIL1;

	p_device_proc_entry = create_proc_entry("device",
			S_IFREG | S_IRUGO, p_mcua0_dir);
	if( !p_device_proc_entry ) goto FAIL2;

	p_device_proc_entry->proc_fops = &rs_proc_fops;

	return(0);

FAIL2:
	if(p_mcua0_dir) remove_proc_entry(p_mcua0_dir->name, p_moxa_dir);
FAIL1:
	if(p_moxa_dir) remove_proc_entry(p_moxa_dir->name, &proc_root);
FAIL0:
	return(ENXIO); // no such device or address
#endif
}

void rs485_remove_proc(void) {
#if(LINUX_VERSION_CODE < KERNEL_VERSION(2,3,98))
	proc_unregister(&mcua0_dir, device_proc_entry.low_ino);
	proc_unregister(&moxa_dir, mcua0_dir.low_ino);
	proc_unregister(&proc_root, moxa_dir.low_ino);
#else
	if(p_device_proc_entry) remove_proc_entry(p_device_proc_entry->name, p_mcua0_dir);
	if(p_mcua0_dir) remove_proc_entry(p_mcua0_dir->name, p_moxa_dir);
	if(p_moxa_dir) remove_proc_entry(p_moxa_dir->name, &proc_root);
#endif
	return;
}
